@@ -1,58 +1,67 @@
-#' Synoptic tables and calculation of fidelity and differential species character
+#' Synoptic tables and calculation of cluster-wise frequencies, fidelity and
+#' differential species character
 #'
-#' @description This function calculates an unordered synoptic table for vegetation unit analysis from
-#' a species-sample dataframe and a numeric vector of cluster identity input.
-#' Synoptic table options for displaying species in clusters is absolute or percentage frequency, mean/median cover values,
-#' differential character (positive, negative, positive-negative, according to Tsiripidis et al. 2009) or fidelity phi
-#' (Bruelheide 2000).
-#' Created unordered synoptic table can be sorted automatically with \code{\link{synsort}} function in this package.
+#' @description Synoptic tables are a tool for the visualization and interpretation of previously
+#' defined plant species groups (clusters), e.g. from cluster analysis or classification methods.
+#' They help to determine characteristic patterning of species occurrences in plant communities
+#' by calculating cluster-wise percentage or absolute frequencies, mean/median cover values, fidelity
+#' (phi) or differential species character.
+#' \code{syntable} function calculates an unordered synoptic table for plant community analysis, using
+#' an input species-sample dataframe and a numeric vector of cluster identity input.
+#' The unordered output table can be sorted automatically with \code{\link[goeveg]{synsort}} function
+#' in this package.
 #'
 #' @param spec Species matrix or dataframe with species in columns and samples in rows.
-#' Values must be numeric ("." as decimal character) or integer.  Missing values, NA or NaN are not allowed.
-#' Species and sample names must be defined as column- and rownames.
-#' @param cluster Integer vector with classification cluster identity. Ensure matching order of cluster identity
-#' and samples in dataframe for correct allocation of cluster numbers to samples.
-#' @param abund Data input type. Define whether input species matrix or dataframe is presence/absence data
-#' (\code{abund = "freq"}) or percentage cover (\code{abund = "perc"}, default).
-#' @param type Type of synoptic table output, \code{type = c("percfreq", "totalfreq", "mean", "median", "diffspec", "phi")}.
-#' See Details for description of options.
+#' Values must be numeric, with point "." as decimal character, or integer.  Missing values, NA or NaN
+#' are not allowed. Species and sample names must be defined as column- and rownames, respectively.
+#' @param cluster Integer vector with classification cluster identity. Ensure matching order of
+#' cluster identity and samples in dataframe for correct allocation of cluster numbers to samples.
+#' @param abund Data input type. Define whether input species matrix or dataframe is presence/absence
+#' data (\code{abund = "freq"}) or percentage cover (\code{abund = "perc"}, default).
+#' @param type Type of synoptic table output \code{type = c("percfreq", "totalfreq", "mean",
+#' "median", "diffspec", "phi")}. See Details.
 #'
 #' @section Details:
 #' For synoptic table calculation, six types are available.
 #'   \itemize{\item{\code{type = "percfreq" }}{Default, creates a percentage frequency table}
 #'   \item{\code{type = "totalfreq" }}{Creates an absolute frequency table}
-#'   \item{\code{type = "mean" }}{Calculates mean of species values per cluster}
-#'   \item{\code{type = "median" }}{Calculates median of species values per cluster}
-#'   \item{\code{type = "diffspec" }}{Calculates differential character of species according to Tsiripidis et al. 2009.
-#'    Synoptic table gives specification of positive (p), negative (n), positive-negative (pn) or no differential character (-).
-#'    Consider that differential character is always restricted to some and not necessarily all of the other
-#'    units, so regarding percentage frequency is essential for correct interpretation of diagnostic character of species.}
-#'   \item{\code{type = "phi" }}{Calculates fidelity measure phi (algorithm basing on Sokal & Rohlf 1995, Bruelheide 2000).
-#'    Values are ranging between -1 and 1 with high values near 1 indicating high fidelity.}}
+#'   \item{\code{type = "mean" }}{Calculates mean of species values given in \code{spec} per cluster}
+#'   \item{\code{type = "median" }}{Calculates median of species values given in \code{spec} per
+#'    cluster}
+#'   \item{\code{type = "diffspec" }}{Calculates differential character of species according to
+#'    Tsiripidis et al. 2009, with resulting character p = positive, n = negative, pn = positive-
+#'    negative or no differential character (-). Consider that differential character is always
+#'    restricted to some and not necessarily all of the other units, thus considering percentage
+#'    frequency is essential for correct interpretation of the diagnostic species character.}
+#'   \item{\code{type = "phi" }}{Calculates fidelity measure phi (algorithm basing on Sokal & Rohlf
+#'    1995, Bruelheide 2000). Values are ranging between -1 and 1 with high values near 1 indicating
+#'    high fidelity.}}
 #'
-#' For sorting synoptic tables, use \code{\link{synsort}} function.
-#' See also \code{\link[vegdata]{syntab}} function from \code{vegdata} package for creating ordered synoptic tables from turboveg
-#' inputs.
+#' For sorting the output synoptic table, use \code{\link{synsort}} function, providing several
+#' options.
 #'
 #' @return
 #' The function returns a list of result components.
-#'   \item{\code{abund }}{abundance of each species (in decreasing order)}
 #'   \item{\code{$syntable }}{unordered synoptic table for given species and clusters}
-#'   \item{\code{$others }}{names vector of species that are not included in synoptic table due to failing treshold values for
-#'   \code{min1} and/or \code{min2}}
 #'   \item{\code{$samplesize }}{total samples in clusters}
-#' Additionally for differential taxa calculation:
-#'   \item{\code{$onlydiff }}{synoptic table only with differentiating taxa}
-#'   \item{\code{$differentials }}{lists diagnostic taxa for each cluster}
+#'
+#'Additionally for differential species character calculation:
+#'   \item{\code{$onlydiff }}{Synoptic table only with differential species}
+#'   \item{\code{$others }}{List of non-differential species}
+#'   \item{\code{$differentials }}{Lists differential species for each cluster}
+#'
 #'
 #' @references
-#' Bruelheide, H. (2000): A new measure of fidelity and its application to defining species groups. - \emph{Journal of Vegetation Science} 11: 167-178.
+#' Bruelheide, H. (2000): A new measure of fidelity and its application to defining species groups.
+#'  \emph{Journal of Vegetation Science} \strong{11}: 167-178. \doi{https://doi.org/10.2307/3236796}
 #'
-#' Chytry, M., Tichy, L., Holt, J., Botta-Dukat, Z. (2002): Determination of diagnostic species with statistical fidelity measures. \emph{Journal of Vegetation Science} 13: 79-90.
+#' Chytry, M., Tichy, L., Holt, J., Botta-Dukat, Z. (2002): Determination of diagnostic species with
+#'  statistical fidelity measures. \emph{Journal of Vegetation Science} \strong{13}: 79-90. \doi{https://doi.org/10.1111/j.1654-1103.2002.tb02025.x}
 #'
 #' Sokal, R.R. & Rohlf, F.J. (1995): Biometry. 3rd edition Freemann, New York.
 #'
-#' Tsiripidis, I., Bergmeier, E., Fotiadis, G. & Dimopoulos, P. (2009): A new algorithm for the determination of differential taxa. - \emph{Journal of Vegetation Science} 20: 233-240.
+#' Tsiripidis, I., Bergmeier, E., Fotiadis, G. & Dimopoulos, P. (2009): A new algorithm for the
+#' determination of differential taxa. \emph{Journal of Vegetation Science} \strong{20}: 233-240. \doi{https://doi.org/10.1111/j.1654-1103.2009.05273.x}
 #'
 #' @author Jenny Schellenberg (\email{jschell@gwdg.de})
 #' @seealso \code{\link{synsort}}
@@ -80,6 +89,7 @@
 #' phitable
 #' @export
 
+
 syntable <- function(spec, cluster, abund = "perc", type = "percfreq") {
 
   spec <- as.data.frame(apply(spec,2,as.numeric))
@@ -88,36 +98,40 @@ syntable <- function(spec, cluster, abund = "perc", type = "percfreq") {
   names(syntab) <- c(seq(1, max(cluster),1))
   rownames(syntab) <- names(spec)
 
-  if (type=="totalfreq")   {
-    for (i in 1:max(cluster)) {syntab[,i] <- apply(spec[cluster==i,]>0,2,sum)}
-    samplesize <- tapply(rep(1,length(cluster)),cluster,sum)
-    result <- list("syntable" = syntab,
+  if (abund != "perc" & abund != "freq") {
+    stop("Check entry. Argument 'abund' must be either percentages ('perc') or
+         presence/absence data ('freq')")
+  } else {
+    if (type=="totalfreq")   {
+     for (i in 1:max(cluster)) {syntab[,i] <- apply(spec[cluster==i,]>0,2,sum)}
+     samplesize <- tapply(rep(1,length(cluster)),cluster,sum)
+     result <- list("syntable" = syntab,
                    "samplesize" = samplesize)
 
-      } else if (type=="percfreq") {
+     } else if (type=="percfreq") {
     samplesize <- tapply(rep(1,length(cluster)),cluster,sum)
     for (i in 1:max(cluster)) {
-      syntab[,i] <- round(apply(spec[cluster==i,]>0,2,sum)*(100/samplesize[i]), digits = 0)}
+      syntab[,i] <- round(apply(spec[cluster==i,]>0,2,sum)*(100/samplesize[i]), digits=0)}
     result <- list("syntable" = syntab, "samplesize" = samplesize)
 
   } else if (type=="mean" & abund=="perc") {
     samplesize <- tapply(rep(1,length(cluster)),cluster,sum)
-    for (i in 1:max(cluster)) { syntab[,i] <- round(apply(spec[cluster==i,],2,mean), digits = 0) }
+    for (i in 1:max(cluster)) { syntab[,i] <- round(apply(spec[cluster==i,],2,mean), digits=0) }
     result <- list("syntable" = syntab, "samplesize" = samplesize)
 
   } else if (type=="mean" & abund=="freq") {
-    stop("Can't calculate mean cover in clusters with frequency values.")
+    stop("Can?t calculate mean cover in clusters with frequency values.")
 
   } else if (type=="median" & abund=="cover") {
-    for (i in 1:max(cluster)) { syntab[,i] <- round(apply(spec[cluster==i,],2,median), digits = 0)   }
+    for (i in 1:max(cluster)) { syntab[,i] <- round(apply(spec[cluster==i,],2,median), digits=0)   }
     result <- list("syntable" = syntab, "samplesize" = samplesize)
 
   } else if (type=="median" & abund=="freq") {
-    stop("Can't calculate median cover in clusters with frequency values.")
+    stop("Can?t calculate median cover in clusters with frequency values.")
 
   } else if (type=="median" & abund=="perc") {
     samplesize <- tapply(rep(1,length(cluster)),cluster,sum)
-    for (i in 1:max(cluster)) { syntab[,i] <- round(apply(spec[cluster==i,],2,median), digits = 0) }
+    for (i in 1:max(cluster)) { syntab[,i] <- round(apply(spec[cluster==i,],2,median), digits=0) }
     result <- list("syntable" = syntab, "samplesize" = samplesize)
 
   } else if (type=="diffspec") {
@@ -128,7 +142,7 @@ syntable <- function(spec, cluster, abund = "perc", type = "percfreq") {
 
     small <- data.frame(matrix(NA, nrow=length(rownames(syn)), ncol=length(group)))
     names(small) <- group
-    for (i in 1:length(rownames(syn))) { small[i,] <- sort(syn[i,]) }
+    for (i in 1:length(rownames(syn))) { small[i,] <- sort(as.numeric(syn[i,])) }
 
     Avsmall <- data.frame(matrix(NA, nrow=length(rownames(syn)), ncol=length(group)))
     Avsmall[,1] <- small[,1]
@@ -153,7 +167,7 @@ syntable <- function(spec, cluster, abund = "perc", type = "percfreq") {
 
     large <- data.frame(matrix(NA, nrow=length(rownames(syn)), ncol=length(group)))
     names(large) <- group
-    for (i in 1:length(rownames(syn))) { large[i,] <- sort(syn[i,], decreasing = T) }
+    for (i in 1:length(rownames(syn))) { large[i,] <- sort(as.numeric(syn[i,]), decreasing = T) }
 
     Avlarge <- data.frame(matrix(NA, nrow=length(rownames(syn)), ncol=length(group)))
     Avlarge[,1] <- large[,1]
@@ -308,6 +322,7 @@ syntable <- function(spec, cluster, abund = "perc", type = "percfreq") {
       result <- list("syntable" = phitab,
                      "samplesize" = samplesize)
 
-  } else {stop("Can't calculate synoptic table. Define correct type of species matrix values to use (abund = c('cover', 'freq')). \nCheck correct type of synoptic table output type (type = c('totalfreq', 'percfreq', 'mean', 'median', 'diffspec')).")
+  } else {stop("Cannot calculate synoptic table. Define correct type of species matrix values to use (abund = c('cover', 'freq')). \nCheck correct type of synoptic table output type (type = c('totalfreq', 'percfreq', 'mean', 'median', 'diffspec')).")
+  }
   }
 }
